@@ -182,17 +182,22 @@ class StorableReader:
         # делаем класс F одинаковым с классом self.bless[classname]
         # объекты класса F будут "instanceof A"
         a_class = self.bless[classname] if classname in self.bless else type(classname_python, (
-        (list if isinstance(sv, list) else object),), {})
-
-        obj = a_class.__new__(a_class)
+        type(sv),), {})
 
         # переписываем свойства
         if isinstance(sv, list):
+            obj = a_class.__new__(a_class)
             for v in sv:
                 obj.append(v)
-        else:
+        elif isinstance(sv, dict):
+            obj = a_class.__new__(a_class)
             for key, val in sv.items():
                 setattr(obj, key, val)
+        else:
+            obj = a_class(sv)
+            #setattr(obj, "scalar", sv)
+
+
         return obj
 
     def retrieve_blessed(self):
